// -*- C++ -*- generated by wxGlade 0.2.2 on Sat Dec 27 21:22:24 2003

#include "wx/config.h"
#include "MainFrame.h"
#include "stdio.h"
#include "stdarg.h"

#include "ibpp.h"
#include "../FBExport.h"
#include "../ParseArgs.h"
#include "OutputFrame.h"
MainFrame* main_frame;
//---------------------------------------------------------------------------------------
// we take all output from FBExport engine and output to TextCtrl
void FBExport::Printf(const char *format, ...)
{
	wxString line;

	va_list argPtr;
	va_start(argPtr, format);
	line.PrintfV(format, argPtr);
	va_end(argPtr);

	// CLI version knows nothing about wxWindows, so GUI is a: void *
	// we have to cast it to the real stuff
	wxTextCtrl *text_box = (wxTextCtrl *)GUI;
	text_box->AppendText(line);

	// update but don't allow user to close form or something similar
	#ifdef __WXMSW__
	::wxSafeYield();
	#endif
}
//-----------------------------------------------------------------------------
// EVENTS:
//-----------------------------------------------------------------------------
BEGIN_EVENT_TABLE(MainFrame, wxFrame)
	EVT_BUTTON(MainFrame::ID_db_button, MainFrame::OnDbButtonClick)
	EVT_BUTTON(MainFrame::ID_wizard_button, MainFrame::OnWizardButtonClick)
	EVT_BUTTON(MainFrame::ID_filename_button, MainFrame::OnFilenameButtonClick)
	EVT_BUTTON(MainFrame::ID_export_button, MainFrame::OnExportButtonClick)
	EVT_BUTTON(MainFrame::ID_import_button, MainFrame::OnImportButtonClick)
	EVT_BUTTON(MainFrame::ID_execute_button, MainFrame::OnExecuteButtonClick)
	EVT_BUTTON(MainFrame::ID_about_button, MainFrame::OnAboutButtonClick)
	EVT_BUTTON(MainFrame::ID_datetime_help_button, MainFrame::OnDatetimeHelpButtonClick)
	EVT_BUTTON(MainFrame::ID_list_button, MainFrame::OnListButtonClick)
END_EVENT_TABLE()
//-----------------------------------------------------------------------------
void MainFrame::OnAboutButtonClick(wxCommandEvent& WXUNUSED(event))
{
	::wxMessageBox(
		"FBExport GUI by Milan Babuskov.\n"
		"\nThis program uses the same code as the command-line\n"
		"version of FBExport, so they are completely compatible\n"
		"\nFBExport is a tool for exporting/importing data\n"
		"with Firebird and InterBase databases\n"
		"\nIBPP library is used for database access (www.ibpp.org)\n"
		"wxWindows is used for GUI (www.wxWindows.org)\n"
		"wxGlade is used to build the GUI (wxglade.sf.net)\n"
		"\nContact me at: mbabuskov@yahoo.com\n"
		"\nVisit http://fbexport.sourceforge.net for more info.",
		"About FBExport GUI",
		wxOK|wxICON_INFORMATION);
}
//-----------------------------------------------------------------------------
void MainFrame::OnDatetimeHelpButtonClick(wxCommandEvent& WXUNUSED(event))
{
	::wxMessageBox(
		"When exporting as CVS or Inserts you can specify format of date, time and timestamp columns.\n\n"
		"Default date format is D.M.Y which is output as 31.01.2000.\n\n"
		"D - day of month 01-31\n"
		"d - day of month 1-31\n"
		"M - month 01-12\n"
		"m - month 1-12\n"
		"y - year 00-99\n"
		"Y - year 0000-9999\n\n"
		"Default time format is H:M:S which is output as 23:59:59\n\n"
		"h - hour 0-23\n"
		"H - hour 01-23\n"
		"m - minute 0-59\n"
		"M - minute 00-59\n"
		"s - second 0-59\n"
		"S - second 00-59\n\n"
		"All other characters are output as they are, so you can use colon, slashes, whatever.\n"
		"If you wish to output just the date portion of timestamp column, empty the time format\n"
		"field and fbexport will remove the trailing space character (between date and time).",
		"About date and time formatting",
		wxOK|wxICON_INFORMATION);
}
//-----------------------------------------------------------------------------
void MainFrame::OnDbButtonClick(wxCommandEvent& WXUNUSED(event))
{
	wxString path = ::wxFileSelector(wxT("Select database file"));
	if (!path.empty())
		db_text_ctrl->SetValue(path);
}
//-----------------------------------------------------------------------------
void MainFrame::OnWizardButtonClick(wxCommandEvent& WXUNUSED(event))
{
	const wxString actions[] = { "Export data", "Import data" };
	int action = ::wxGetSingleChoiceIndex("What do you want to do?", "SQL Wizard", 2, actions, this);
	if (action == -1)
		return;

	int object_type = 0; 	// tables
	const wxString object_names[] = { "Table", "View", "Stored procedure" };
	if (action == 0)		// export data: tables,views,SPs
	{
		object_type = ::wxGetSingleChoiceIndex("Select type of database object", "SQL Wizard", 3, object_names, this);
		if (object_type == -1)
			return;
	}

	// load list of all objects of "object_type" type
	std::string sql[] = {
		"select RDB$RELATION_NAME from RDB$RELATIONS where (RDB$SYSTEM_FLAG = 0 or RDB$SYSTEM_FLAG is null) "
		"and RDB$VIEW_SOURCE is null ORDER BY 1",

		"select RDB$RELATION_NAME from RDB$RELATIONS where RDB$SYSTEM_FLAG = 0 "
		"and RDB$VIEW_SOURCE is not null ORDER BY 1",

		"select RDB$PROCEDURE_NAME from RDB$PROCEDURES where (RDB$SYSTEM_FLAG = 0 "
		"or RDB$SYSTEM_FLAG is null) ORDER BY 1"
	};

	// get columns of each object type
	std::string sql_columns[] = {
		"select rdb$field_name from rdb$relation_fields where rdb$relation_name = ? order by 1",
		"select rdb$field_name from rdb$relation_fields where rdb$relation_name = ? order by 1",
		"select rdb$parameter_name, rdb$parameter_type from rdb$procedure_parameters where rdb$procedure_name= ? "
		"order by rdb$parameter_number"
	};

	// connect to the database, load stuff...
	try
	{
		IBPP::Database db1 = IBPP::DatabaseFactory(
			host_text_ctrl->GetValue().c_str(),
			db_text_ctrl->GetValue().c_str(),
			user_text_ctrl->GetValue().c_str(),
			pass_text_ctrl->GetValue().c_str(),
			"",
			charset_combo_box->GetValue().c_str(),
			""
		);
		IBPP::Transaction tr1;
		db1->Connect();
		tr1 = IBPP::TransactionFactory(db1, IBPP::amWrite);
		tr1->Start();
		IBPP::Statement st1 = IBPP::StatementFactory(db1, tr1);

		wxArrayString objects;
		st1->Prepare(sql[object_type]);
		st1->Execute();
		while (st1->Fetch())
		{
			std::string temp;
			st1->Get(1, temp);
			wxString s = temp.c_str();
			objects.Add(s.Trim());
		}
		tr1->Commit();		// commit since we're waiting for user input and we don't want
							// transaction to "hang"

		if (objects.GetCount() == 0)
		{
			::wxMessageBox(wxString("There are no ") + object_names[object_type] + wxString("s in that database"), "SQL Wizard");
			return;
		}

		// let the user select an object
		int object = ::wxGetSingleChoiceIndex(wxString("Please select one ")+object_names[object_type], "SQL Wizard", objects, this);
		if (object == -1)
			return;

		// ask the user for columns of the object
		tr1->Start();
		IBPP::Statement st2 = IBPP::StatementFactory(db1, tr1);

		wxArrayString columns;
		wxArrayString params;
		st1->Prepare(sql_columns[object_type]);
		st1->Set(1, objects[object]);			// insert object name into sql
		st1->Execute();
		while (st1->Fetch())
		{
			std::string temp;
			int i=1;
			st1->Get(1, temp);
			wxString s = temp.c_str();
			if (object_type == 2)	// SPs
				st1->Get(2, &i);
			if (i == 1)
				columns.Add(s.Trim());
			else
				params.Add(s.Trim());
		}
		tr1->Commit();		// commit since we're waiting for user input and we don't want
							// transaction to "hang"

		if (columns.GetCount() == 0)
		{
			::wxMessageBox(objects[object] + wxString(" has no columns/parameters to use."), "SQL Wizard");
			return;
		}

		wxArrayInt selected_columns;
		::wxGetMultipleChoices(selected_columns, "Select one or more... (use ctrl key)",  "SQL Wizard", columns, this);

		if (selected_columns.GetCount() < 1)
			return;

		// construct SQL statement and write into sql_text_ctrl
		wxString column_list;
		for (size_t i=0; i<selected_columns.GetCount(); i++)
		{
			if (i)
				column_list += ", ";
			column_list += columns[selected_columns[i]];
		}

		wxString SQL;
		if (action == 0)	// export
		{
			SQL = "SELECT " + column_list + "\nFROM " + objects[object];
			if (object_type == 2)	// SPs
			{
				SQL += "(";
				for (size_t i=0; i<params.GetCount(); i++)
				{
					if (i)
						SQL += ", ";
					SQL += params[i];
				}
				SQL += ")";
			}
		}
		else				// import
		{
			SQL = "INSERT INTO " + objects[object] + "\n(" + column_list + ")";
		}

		sql_text_ctrl->SetValue(SQL);
	}
	catch (IBPP::Exception &e)
	{
		::wxMessageBox(e.ErrorMessage(), "Error!", wxOK);
	}
	catch (...)
	{
		::wxMessageBox("ERROR!\nA non-IBPP C++ runtime exception occured !\n\n", "Error!", wxOK);
	}
}
//-----------------------------------------------------------------------------
void MainFrame::OnFilenameButtonClick(wxCommandEvent& WXUNUSED(event))
{
	wxString path = ::wxFileSelector(wxT("Select file"));
	if (!path.empty())
		text_ctrl_1->SetValue(path);
}
//-----------------------------------------------------------------------------
void MainFrame::OnExportButtonClick(wxCommandEvent& WXUNUSED(event))
{
	// check if insert - offer to recreate
	Go(xopSelect);
}
//-----------------------------------------------------------------------------
void MainFrame::OnImportButtonClick(wxCommandEvent& WXUNUSED(event))
{
	// check if select - recreate
	Go(xopInsert);
}
//-----------------------------------------------------------------------------
void MainFrame::OnExecuteButtonClick(wxCommandEvent& WXUNUSED(event))
{
	Go(xopExec);
}
//-----------------------------------------------------------------------------
void MainFrame::OnListButtonClick(wxCommandEvent& WXUNUSED(event))
{
	Go(xopListUsers);
}
//-----------------------------------------------------------------------------
void MainFrame::WriteConfig()
{
	wxConfig config("FBExport");
	config.Write("Host", host_text_ctrl->GetValue());
	config.Write("Username", user_text_ctrl->GetValue());
	config.Write("Password", pass_text_ctrl->GetValue());
	config.Write("Database", db_text_ctrl->GetValue());
	config.Write("SQL", sql_text_ctrl->GetValue());
	config.Write("Filename", text_ctrl_1->GetValue());
	config.Write("Charset", charset_combo_box->GetValue());
	config.Write("Errors", erros_text_ctrl_copy->GetValue());
	config.Write("Checkpoint", checkpoint_text_ctrl_copy->GetValue());
	config.Write("Trim", trim_checkbox->IsChecked());
	config.Write("Rollback", rollback_checkbox->IsChecked());
	config.Write("FullInsert", fullinsert_checkbox->IsChecked());
	config.Write("ExportFormat", format_radio_box->GetSelection());
	config.Write("DateFormat", dateformat_text_ctrl->GetValue());
	config.Write("TimeFormat", timeformat_text_ctrl->GetValue());
}
//-----------------------------------------------------------------------------
void MainFrame::Go(XOperation operation)
{
	WriteConfig();	// just in case something crashes

	Arguments args;
	args.Username     = user_text_ctrl->GetValue().c_str();
    args.Password     = pass_text_ctrl->GetValue().c_str();
    args.Database     = db_text_ctrl->GetValue().c_str();
    args.Host         = host_text_ctrl->GetValue().c_str();
    args.SQL	      = sql_text_ctrl->GetValue().c_str();
    args.Filename     = text_ctrl_1->GetValue().c_str();
	args.Charset      = charset_combo_box->GetValue().c_str();
	args.ExportFormat = (XExportFormat)format_radio_box->GetSelection();
	args.DateFormat   = dateformat_text_ctrl->GetValue().c_str();
	args.TimeFormat   = timeformat_text_ctrl->GetValue().c_str();

	long val;
	if (!checkpoint_text_ctrl_copy->GetValue().ToLong(&val))
		val = 0;
    args.CheckPoint = val;

	if (!erros_text_ctrl_copy->GetValue().ToLong(&val))
		val = 0;
    args.IgnoreErrors = val;

    args.Rollback = rollback_checkbox->IsChecked();
    args.TrimChars = trim_checkbox->IsChecked();

	output_frame->output_text_ctrl->Clear();
	output_frame->output_text_ctrl->AppendText("------------ STARTING FBExport ENGINE -----------\n");
	output_frame->Show();
	output_frame->Raise();
	::wxSafeYield();

    args.Operation = operation;
	if (operation == xopInsert && fullinsert_checkbox->IsChecked())
		args.Operation = xopInsertFull;

	FBExport F;
	F.GUI = (void *)output_frame->output_text_ctrl;
	F.Init(&args);
	output_frame->output_text_ctrl->AppendText("\n\n------------ TASK COMPLETE -----------");
	::wxSafeYield();
}
//---------------------------------------------------------------------------------------
MainFrame::MainFrame(wxWindow* parent, int id, const char* title, const wxPoint& pos, const wxSize& size, long style):
    wxFrame(parent, id, title, pos, size, wxDEFAULT_FRAME_STYLE)
{
    // begin wxGlade: MainFrame::MainFrame
    panel_5 = new wxPanel(this, -1);
    label_17 = new wxStaticText(panel_5, -1, "Host (server)");
    host_text_ctrl = new wxTextCtrl(panel_5, -1, "LOCALHOST");
    label_2 = new wxStaticText(panel_5, -1, "Charset");
    const wxString charset_combo_box_choices[] = {
		wxT("NONE"),
		wxT("ASCII"),
		wxT("BIG_5"),
		wxT("CYRL"),
		wxT("DOS437"),
		wxT("DOS850"),
		wxT("DOS852"),
		wxT("DOS857"),
		wxT("DOS860"),
		wxT("DOS861"),
		wxT("DOS863"),
		wxT("DOS865"),
		wxT("EUCJ_0208"),
		wxT("GB_2312"),
		wxT("ISO8859_1"),
		wxT("ISO8859_2"),
		wxT("KSC_5601"),
		wxT("NEXT"),
		wxT("OCTETS"),
		wxT("SJIS_0208"),
		wxT("UNICODE_FSS"),
		wxT("WIN1250"),
		wxT("WIN1251"),
		wxT("WIN1252"),
		wxT("WIN1253"),
		wxT("WIN1254")
    };
    charset_combo_box = new wxComboBox(panel_5, -1, "", wxDefaultPosition, wxDefaultSize, 26, charset_combo_box_choices, wxCB_DROPDOWN|wxCB_READONLY);
    about_button = new wxButton(panel_5, ID_about_button, "About FBExport...");
    label_18 = new wxStaticText(panel_5, -1, "Username");
    user_text_ctrl = new wxTextCtrl(panel_5, -1, "SYSDBA");
    label_19 = new wxStaticText(panel_5, -1, "Password");
    pass_text_ctrl = new wxTextCtrl(panel_5, -1, "masterkey", wxDefaultPosition, wxDefaultSize, wxTE_PASSWORD);
    label_20 = new wxStaticText(panel_5, -1, "Database");
    db_text_ctrl = new wxTextCtrl(panel_5, -1, "/baze/test.gdb");
    db_button = new wxButton(panel_5, ID_db_button, "...");
    label_21 = new wxStaticText(panel_5, -1, "Type SQL yourself or ...");
    wizard_button = new wxButton(panel_5, ID_wizard_button, "Run SQL Wizard");
	fullinsert_checkbox = new wxCheckBox(panel_5, -1, "Use SQL with :1, :2, :3... parameters (for import)");
    sql_text_ctrl = new wxTextCtrl(panel_5, -1, "Export:   SELECT ... FROM table WHERE ... etc.\n\nImport:   INSERT INTO table (...)", wxDefaultPosition, wxDefaultSize, wxTE_PROCESS_ENTER|wxTE_PROCESS_TAB|wxTE_MULTILINE);
    label_1 = new wxStaticText(panel_5, -1, "Input/output file");
    text_ctrl_1 = new wxTextCtrl(panel_5, -1, "");
    filename_button = new wxButton(panel_5, ID_filename_button, "...");
    trim_checkbox = new wxCheckBox(panel_5, -1, "Trim chars (to reduce file size)");
    rollback_checkbox = new wxCheckBox(panel_5, -1, "Rollback transaction on errors");
    label_22_copy = new wxStaticText(panel_5, -1, "Set checkpoint at every");
    checkpoint_text_ctrl_copy = new wxTextCtrl(panel_5, -1, "1000");
    label_23_copy = new wxStaticText(panel_5, -1, "rows");
    label_24_copy = new wxStaticText(panel_5, -1, "Ignore up to");
    erros_text_ctrl_copy = new wxTextCtrl(panel_5, -1, "0");
    label_25_copy = new wxStaticText(panel_5, -1, "errors (-1 ignores all)");
    const wxString format_radio_box_choices[] = {
        "FBExport format",
        "Comma Separated Values (CSV)",
        "INSERT statements"
    };
    format_radio_box = new wxRadioBox(panel_5, -1, "Export (output) file format", wxDefaultPosition, wxDefaultSize, 3, format_radio_box_choices, 1, wxRA_SPECIFY_COLS);
    label_3 = new wxStaticText(panel_5, -1, "Date && time format");
    dateformat_text_ctrl = new wxTextCtrl(panel_5, -1, "D.M.Y");
    timeformat_text_ctrl = new wxTextCtrl(panel_5, -1, "H:M:S");
    datetime_help_button = new wxButton(panel_5, ID_datetime_help_button, "?");
    export_button = new wxButton(panel_5, ID_export_button, "Export");
    import_button = new wxButton(panel_5, ID_import_button, "Import");
    execute_button = new wxButton(panel_5, ID_execute_button, "Execute SQL");
    list_button = new wxButton(panel_5, ID_list_button, "List connected users");

    set_properties();
    do_layout();
    // end wxGlade

	// load previous settings from registry or ini file
	wxConfig config("FBExport");
	wxString str;
	if (config.Read("Host", &str))
		host_text_ctrl->SetValue(str);
	if (config.Read("Username", &str))
		user_text_ctrl->SetValue(str);
	if (config.Read("Password", &str))
		pass_text_ctrl->SetValue(str);
	if (config.Read("Database", &str))
		db_text_ctrl->SetValue(str);
	if (config.Read("SQL", &str))
		sql_text_ctrl->SetValue(str);
	if (config.Read("Filename", &str))
		text_ctrl_1->SetValue(str);
	if (config.Read("Errors", &str))
		erros_text_ctrl_copy->SetValue(str);
	if (config.Read("Checkpoint", &str))
		checkpoint_text_ctrl_copy->SetValue(str);
	if (config.Read("Charset", &str))
		charset_combo_box->SetSelection(charset_combo_box->FindString(str));
	bool b;
	if (config.Read("Trim", &b))
		trim_checkbox->SetValue(b);
	if (config.Read("Rollback", &b))
		rollback_checkbox->SetValue(b);
	if (config.Read("DateFormat", &str))
		dateformat_text_ctrl->SetValue(str);
	if (config.Read("TimeFormat", &str))
		timeformat_text_ctrl->SetValue(str);
	if (config.Read("FullInsert", &b))
		fullinsert_checkbox->SetValue(b);
	int i;
	if (config.Read("ExportFormat", &i))
		format_radio_box->SetSelection(i);
}
//---------------------------------------------------------------------------------------
void MainFrame::set_properties()
{
    // begin wxGlade: MainFrame::set_properties
    SetTitle("FBExport GUI");
    charset_combo_box->SetSelection(0);
    db_button->SetSize(wxSize(21, 21));
    sql_text_ctrl->SetSize(wxSize(462, 61));
    filename_button->SetSize(wxSize(21, 21));
    format_radio_box->SetSelection(0);
    datetime_help_button->SetSize(wxSize(21, 21));
    // end wxGlade
    SetTitle("FBExport GUI 1.07, using FBExport " FBEXPORT_VERSION " engine");

	/* XPM */
	static char * icon_xpm[] = {
	"32 32 4 1",
	" 	c None",
	".	c #000000",
	"+	c #C0C0C0",
	"@	c #808080",
	"................................",
	".+++++++++++++++@@@@@@@@@@@@@@@.",
	".+++++++++++++++@@@@@@@@@@@@@@@.",
	".+++@@@@@@@@@+++@@+++++++@@@@@@.",
	".+++@@@@@@@@@+++@@++++++++@@@@@.",
	".+++@@@@@@@@@+++@@+++@@@++@@@@@.",
	".+++@@@+++++++++@@+++@@@++@@@@@.",
	".+++@@@+++++++++@@++++++++@@@@@.",
	".+++@@@@@@++++++@@+++++++++@@@@.",
	".+++@@@@@@++++++@@+++@@@@++@@@@.",
	".+++@@@@@@++++++@@+++@@@@++@@@@.",
	".+++@@@+++++++++@@+++@@@@++@@@@.",
	".+++@@@+++++++++@@+++++++++@@@@.",
	".+++@@@+++++++++@@++++++++@@@@@.",
	".+++++++++++++++@@@@@@@@@@@@@@@.",
	".+++++++++++++++@@@@@@@@@@@@@@@.",
	".@@@@@@@@@@@@@@@+++++++++++++++.",
	".@@@@@@@@@@@@@@@+++++++++++++++.",
	".@@@@@@@@@@@@@@@++++@@@@@@@@+++.",
	".@@@++@@@@@@++@@+++@@@@@@@@@+++.",
	".@@@+++@@@@+++@@+++@@@@@@@@@+++.",
	".@@@@+++@@+++@@@+++@@@+++++++++.",
	".@@@@@++++++@@@@+++@@@+@@@@@+++.",
	".@@@@@@++++@@@@@+++@@@+@@@@@+++.",
	".@@@@@@++++@@@@@+++@@@+@@@@@+++.",
	".@@@@@++++++@@@@+++@@@+++@@@+++.",
	".@@@@+++@@+++@@@+++@@@@@@@@@+++.",
	".@@@+++@@@@+++@@+++@@@@@@@@@+++.",
	".@@@++@@@@@@++@@+++@@@@@@@@@+++.",
	".@@@@@@@@@@@@@@@+++++++++++++++.",
	".@@@@@@@@@@@@@@@+++++++++++++++.",
	"................................"};

	output_frame = new OutputFrame(this, -1, "");
	output_frame->Show();
	Show();
    wxIcon icon(icon_xpm);
    SetIcon(icon);
}
//---------------------------------------------------------------------------------------
void MainFrame::do_layout()
{
    // begin wxGlade: MainFrame::do_layout
    wxBoxSizer* sizer_1 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_15 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_24 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_25 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_9 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_5 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_8 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_6 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_26 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_23 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_2 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_20 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_19 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_17 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_16 = new wxBoxSizer(wxHORIZONTAL);
    wxBoxSizer* sizer_3 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_4 = new wxBoxSizer(wxHORIZONTAL);
    sizer_16->Add(label_17, 0, wxALL, 4);
    sizer_16->Add(host_text_ctrl, 0, wxLEFT|wxRIGHT, 8);
    sizer_16->Add(label_2, 0, wxALL, 4);
    sizer_16->Add(charset_combo_box, 0, wxLEFT|wxRIGHT, 2);
    sizer_4->Add(about_button, 0, wxLEFT|wxEXPAND, 20);
    sizer_3->Add(sizer_4, 1, wxALIGN_RIGHT, 0);
    sizer_16->Add(sizer_3, 1, wxEXPAND, 0);
    sizer_15->Add(sizer_16, 0, wxALL|wxEXPAND, 2);
    sizer_17->Add(label_18, 0, wxALL, 4);
    sizer_17->Add(user_text_ctrl, 0, wxLEFT|wxRIGHT, 8);
    sizer_17->Add(label_19, 0, wxALL, 4);
    sizer_17->Add(pass_text_ctrl, 0, wxLEFT, 2);
    sizer_15->Add(sizer_17, 0, wxALL|wxEXPAND, 2);
    sizer_19->Add(label_20, 0, wxLEFT|wxRIGHT|wxTOP, 4);
    sizer_19->Add(db_text_ctrl, 1, wxLEFT, 7);
    sizer_19->Add(db_button, 0, wxLEFT|wxRIGHT, 1);
    sizer_15->Add(sizer_19, 0, wxALL|wxEXPAND, 2);
    sizer_20->Add(label_21, 0, wxTOP|wxALIGN_CENTER_VERTICAL, 16);
    sizer_20->Add(wizard_button, 0, wxTOP|wxALIGN_BOTTOM, 10);
    sizer_20->Add(fullinsert_checkbox, 0, wxLEFT|wxRIGHT|wxTOP|wxALIGN_CENTER_VERTICAL , 10);
    sizer_15->Add(sizer_20, 0, wxLEFT|wxEXPAND, 3);
    sizer_15->Add(sql_text_ctrl, 1, wxALL|wxEXPAND, 2);
    sizer_2->Add(label_1, 0, wxALL, 4);
    sizer_2->Add(text_ctrl_1, 1, 0, 5);
    sizer_2->Add(filename_button, 0, wxLEFT|wxRIGHT, 1);
    sizer_15->Add(sizer_2, 0, wxEXPAND, 0);
    sizer_6->Add(trim_checkbox, 0, wxALL, 4);
    sizer_6->Add(rollback_checkbox, 0, wxALL, 4);
    sizer_23->Add(label_22_copy, 0, wxALL, 4);
    sizer_23->Add(checkpoint_text_ctrl_copy, 0, 0, 0);
    sizer_23->Add(label_23_copy, 0, wxALL, 4);
    sizer_6->Add(sizer_23, 0, wxALL|wxEXPAND, 1);
    sizer_26->Add(label_24_copy, 0, wxALL, 4);
    sizer_26->Add(erros_text_ctrl_copy, 0, 0, 0);
    sizer_26->Add(label_25_copy, 0, wxALL, 4);
    sizer_6->Add(sizer_26, 0, wxALL|wxEXPAND, 1);
    sizer_5->Add(sizer_6, 1, wxEXPAND, 0);
    sizer_8->Add(format_radio_box, 0, wxALL, 2);
    sizer_5->Add(sizer_8, 0, 0, 0);
    sizer_15->Add(sizer_5, 0, wxEXPAND, 0);
    sizer_9->Add(label_3, 0, wxALL, 4);
    sizer_9->Add(dateformat_text_ctrl, 0, 0, 0);
    sizer_9->Add(timeformat_text_ctrl, 0, 0, 0);
    sizer_9->Add(datetime_help_button, 0, wxLEFT|wxRIGHT, 1);
    sizer_15->Add(sizer_9, 0, wxRIGHT|wxTOP|wxEXPAND, 3);
    sizer_25->Add(export_button, 0, wxALL, 2);
    sizer_25->Add(import_button, 0, wxALL, 2);
    sizer_25->Add(execute_button, 0, wxALL, 2);
    sizer_25->Add(list_button, 0, wxALL, 2);
    sizer_24->Add(sizer_25, 1, wxALIGN_CENTER_HORIZONTAL, 0);
    sizer_15->Add(sizer_24, 0, wxALL|wxEXPAND, 4);
    panel_5->SetAutoLayout(true);
    panel_5->SetSizer(sizer_15);
    sizer_15->Fit(panel_5);
    sizer_15->SetSizeHints(panel_5);
    sizer_1->Add(panel_5, 1, wxEXPAND, 0);
    SetAutoLayout(true);
    SetSizer(sizer_1);
    sizer_1->Fit(this);
    sizer_1->SetSizeHints(this);
    Layout();
    // end wxGlade
}
//---------------------------------------------------------------------------------------

